**Google Dork**
================

**A Powerful CLI Tool for Google Search**

Google Dork is a CLI tool that enables you to search Google with ease and speed. With Google Dork, you can search for:

* Structured domain information
* Quickly search Google with complex queries
* Search for domain, filetype, intext, intitle, and inurl information with ease

**Features**
--------

* Quickly search Google with complex queries
* Supports searching by domain, filetype, intext, intitle, and inurl
* Search for information with advanced query syntax

**Getting Started**
---------------

1. Download Google Dork CLI module [here](https://github.com/dword32bit/google-dork/releases/download/v1.0.0/google_dork-1.0.tar.gz)
2. Install Google Dork using `pip install google_dork-*.tar.gz`

**Usage**
-----------------

1. import on your python project
2. `from google_dork import GoogleDork`

**Documentations**
-----------------
*[here](https://github.com/dword32bit/google-dork/blob/main/documentations.md)*

*or*
if you pusing, you can use like my code [simpledork](https://github.com/dword32bit/simpledork.git) or [guidork](https://github.com/dword32bit/guidork.git)

**Contributors**
------------

* [dword32bit](https://github.com/dword32bit) - creator of Google Dork CLI without API

* [bri-anadi](https://github.com/bri-anadi) - creator of Google Dork CLI without API

**License**
-------

Google Dork is licensed under the MIT License. You are free to use, copy, and modify this code for your own purposes.

**Development**
--------------

* Python 3.6+
* BeautifulSoup 4
* requests 2.25+
